
%global debug_package   %{nil}
%global _find_debuginfo_dwz_opts %{nil}
%global _dwz_low_mem_die_limit 0

%global import_path github.com/cri-o/cri-o
%global service_name crio
%global golang_version 1.13.15

Name: cri-o
Version: 1.19.1
Release: 2%{?dist}
ExcludeArch: ppc64
Summary: Kubernetes Container Runtime Interface for OCI-based containers
License: ASL 2.0
URL: https://%{import_path}
Vendor:  Oracle America
Source0: %{name}-%{version}.tar.bz2
Source3: %{service_name}-network.sysconfig
Source4: %{service_name}-storage.sysconfig
Source5: %{service_name}-metrics.sysconfig
Patch0: ocr-workaround.patch.txt
BuildRequires: golang >= %{golang_version}
BuildRequires: btrfs-progs-devel
BuildRequires: device-mapper-devel
BuildRequires: git
BuildRequires: glib2-devel
BuildRequires: glibc-static
BuildRequires: gpgme-devel
BuildRequires: libassuan-devel
BuildRequires: libseccomp-devel
BuildRequires: pkgconfig(systemd)
BuildRequires: make
Requires(pre): container-selinux
Requires: %{_sysconfdir}/cri-tools/1.19
Requires: containers-common >= 1:0.1.31-14
Requires: runc >= 1.0.0-16
Obsoletes: ocid <= 0.3
Provides: ocid = %{version}-%{release}
Provides: %{service_name} = %{version}-%{release}
Provides: %{_sysconfdir}/crio/1.19
Requires: kubernetes-cni-plugins >= 0.7.5
#TODO: Remove pinning down of conmon-2.0.21-1 version when conmon moves to 2.1.x
Requires: conmon >= 3:2.0.21-3%{?dist} 
Requires: socat

%description
CRI-O is meant to provide an integration path between OCI conformant runtimes and the kubelet. Specifically, it implements the Kubelet Container Runtime Interface (CRI) using OCI conformant runtimes.

%prep
%setup -q

# process the patches
%patch0

project_dir=$(pwd)
mkdir -p src/github.com/cri-o/cri-o
mkdir -p src/k8s.io/kubernetes
mv $(ls | grep -v "^src$") src/github.com/cri-o/cri-o/.

%build
export GOPATH=$(pwd)
pushd src/github.com/cri-o/cri-o
# TODO FIX ALL THE MISSING ARTIFACTS IN OUR PROXY REPO!!
export GOPROXY=https://proxy.golang.org
# Update mod cache through our golang proxy
go mod download
make GIT_TREE_STATE=clean all
popd

%install
export GOPATH=$(pwd)
pushd src/github.com/cri-o/cri-o

# Create a version file so this project can be bounded as a dependency
install -dp %{buildroot}%{_sysconfdir}/crio
touch %{buildroot}%{_sysconfdir}/crio/1.19

# Edit the crio and crio-wipe unit file to have to correct binary location on the system
sed -i 's/\/local//' contrib/systemd/crio.service
sed -i 's/\/local//' contrib/systemd/crio-wipe.service

# install binaries
install -dp %{buildroot}{%{_bindir},%{_libexecdir}/%{service_name}}
install -p -m 755 bin/%{service_name} %{buildroot}%{_bindir}

# install conf files
install -dp %{buildroot}%{_sysconfdir}/cni/net.d
install -p -m 644 contrib/cni/10-crio-bridge.conf %{buildroot}%{_sysconfdir}/cni/net.d/100-crio-bridge.conf
install -p -m 644 contrib/cni/99-loopback.conf %{buildroot}%{_sysconfdir}/cni/net.d/200-loopback.conf

install -dp %{buildroot}%{_sysconfdir}/sysconfig
install -p -m 644 contrib/sysconfig/%{service_name} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}
install -p -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-network
install -p -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-storage
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/sysconfig/%{service_name}-metrics

make PREFIX=%{buildroot}%{_usr} \
            DESTDIR=%{buildroot} \
            install.bin \
            install.completions \
            install.config \
            install.man \
            install.systemd

./bin/%{service_name} \
      --selinux \
      --cgroup-manager "cgroupfs" \
      --conmon "%{_libexecdir}/%{service_name}/conmon" \
      --cni-plugin-dir "/opt/cni/bin" \
      config > %{service_name}.conf

install -p -m 644 %{service_name}.conf %{buildroot}%{_sysconfdir}/%{service_name}/%{service_name}.conf
popd
mv src/github.com/cri-o/cri-o/*.md .
mv src/github.com/cri-o/cri-o/LICENSE .
mv src/github.com/cri-o/cri-o/THIRD_PARTY_LICENSES.txt .
mv src/github.com/cri-o/cri-o/NOTICE .

%post
%systemd_post %{service_name}

%preun
%systemd_preun %{service_name}

%postun
%systemd_postun_with_restart %{service_name}

%files
%license LICENSE THIRD_PARTY_LICENSES.txt NOTICE
%{_sysconfdir}/crio/1.19
%doc README.md
%{_bindir}/%{service_name}
%{_bindir}/pinns
%{_mandir}/man5/%{service_name}*.5*
%{_mandir}/man8/%{service_name}*.8*
%dir %{_sysconfdir}/%{service_name}
%config(noreplace) %{_sysconfdir}/%{service_name}/%{service_name}.conf
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-storage
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-network
%config(noreplace) %{_sysconfdir}/sysconfig/%{service_name}-metrics
%config(noreplace) %{_sysconfdir}/cni/net.d/100-%{service_name}-bridge.conf
%config(noreplace) %{_sysconfdir}/cni/net.d/200-loopback.conf
%config(noreplace) %{_sysconfdir}/crictl.yaml

%{_unitdir}/crio-wipe.service
/usr/share/bash-completion/completions/crio
/usr/share/bash-completion/completions/crio-status
/usr/share/fish/completions/crio-status.fish
/usr/share/fish/completions/crio.fish
/usr/share/zsh/site-functions/_crio
/usr/share/zsh/site-functions/_crio-status
%{_bindir}/%{service_name}-status

%dir %{_libexecdir}/%{service_name}
%{_unitdir}/%{service_name}.service
%{_unitdir}/cri-o.service
%{_unitdir}/%{service_name}-shutdown.service
%dir %{_datadir}/oci-umount
%dir %{_datadir}/oci-umount/oci-umount.d
%{_datadir}/oci-umount/oci-umount.d/%{service_name}-umount.conf
#crio hook dir
%dir %{_datadir}/containers/oci/hooks.d

%changelog
* Thu May 06 2021 Thomas Tanaka <thomas.tanaka@oracle.com> - 1.19.1-2
- Relax conmon dependency

* Tue Jan 05 2021 Olcne-Builder Jenkins <olcne-builder_us@oracle.com> - 1.19.1-1
- Added Oracle Specifile Files for cri-o
